@@ -3,7 +3,8 @@
 # this repository contains the full copyright notices and license terms.
 
 from trytond.model import ModelView, ModelSQL, fields, tree
-from trytond.transaction import Transaction
+from trytond.exceptions import UserError
+from trytond.i18n import gettext
 
 
 class Category(tree(separator=' / '), ModelSQL, ModelView):
@@ -18,9 +19,6 @@ class Category(tree(separator=' / '), ModelSQL, ModelView):
     def __setup__(cls):
         super(Category, cls).__setup__()
         cls._order.insert(0, ('name', 'ASC'))
-        cls._error_messages.update({
-                'delete_category': (u"The category '%s' has subcategories and therefore can not be deleted."),
-                })
 
     @classmethod
     def validate(cls, categories):
@@ -54,7 +52,10 @@ class Category(tree(separator=' / '), ModelSQL, ModelView):
             return True
         for i in categories:
             if len(i.childs) > 0:
-                cls.raise_user_error('delete_category', (i.name))
+                raise UserError(gettext(
+                    'pim_memos.msg_category_delete',
+                    catname = i.rec_name,
+                    ))
         return super(Category, cls).delete(categories)
 
 # ende Category
