@@ -16,17 +16,17 @@ class ReportOdt(Report):
         pool = Pool()
         IrDate = pool.get('ir.date')
         ExpObj = pool.get(data['model'])(data['id'])
-        
+
         (ext1, cont1, dirprint, titel) = super(ReportOdt, cls).execute(ids, data)
-        titel = '%s-note-%s' % (IrDate.today().strftime('%Y%m%d'), ExpObj.name[:15])
+        titel = '%s-note-%s' % (IrDate.today().strftime('%Y%m%d'), ExpObj.rec_name[:15])
         return (ext1, cont1, dirprint, titel)
 
     @classmethod
-    def get_context(cls, records, data):
-        report_context = super(ReportOdt, cls).get_context(records, data)
+    def get_context(cls, records, header, data):
+        report_context = super(ReportOdt, cls).get_context(records, header, data)
         report_context['islastitem'] = cls.is_last_item
         return report_context
- 
+
     @classmethod
     def is_last_item(cls, liste, item):
         """ check if 'item' is the last in 'liste'
